@@ -35,8 +35,6 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    if (!MAUIAndroid::checkRunTimePermissions({"android.permission.WRITE_EXTERNAL_STORAGE"}))
-        return -1;
 #else
     QApplication app(argc, argv);
 #endif
